@@ -106,9 +106,6 @@ export class Trimmer extends Component {
     if (!source.trim()) {
       throw new Error('source should be valid string');
     }
-    if (!TrimmerManager) {
-      throw new Error('RNTrimmerManager: Native Module installed not correctly');
-    }
     this._retrivePreviewImages();
     this._retriveInfo();
   }
